@@ -1496,7 +1496,7 @@ build_save_distclean_and_execute_command (BasicAutotoolsPlugin* bplugin, BuildPr
 		BuildProgram *new_prog;
 		
 		// Need to run make clean before
-		if (!anjuta_util_dialog_boolean_question (GTK_WINDOW (ANJUTA_PLUGIN (bplugin)->shell), _("Using this new configuration, need to to remove the default one. Do you want to do it ?"), NULL))
+		if (!anjuta_util_dialog_boolean_question (GTK_WINDOW (ANJUTA_PLUGIN (bplugin)->shell), _("Before using this new configuration, the default one needs to be removed. Do you want to do that ?"), NULL))
 		{
 			GError *err;
 			
@@ -1744,6 +1744,8 @@ build_compile_file (BasicAutotoolsPlugin *plugin, const gchar *filename)
 		g_hash_table_insert (target_ext, ".cxx", ".o");
 		g_hash_table_insert (target_ext, ".c++", ".o");
 		g_hash_table_insert (target_ext, ".cc", ".o");
+		g_hash_table_insert (target_ext, ".y", ".o");
+		g_hash_table_insert (target_ext, ".l", ".o");
 		g_hash_table_insert (target_ext, ".in", "");
 		g_hash_table_insert (target_ext, ".in.in", ".in");
 		g_hash_table_insert (target_ext, ".la", ".la");
