@@ -26,24 +26,24 @@
 
 #include <libanjuta/resources.h>
 #include "symbol-db-engine-utils.h"
-
+#include "symbol-db-engine-priv.h"
 
 static GHashTable *pixbufs_hash = NULL;
 
 /*
  * extern declarations 
  */
-extern inline const GdaStatement *
+extern GNUC_INLINE const GdaStatement *
 sdb_engine_get_statement_by_query_id (SymbolDBEngine * dbe, static_query_type query_id);
 
-extern inline const GdaSet *
+extern GNUC_INLINE const GdaSet *
 sdb_engine_get_query_parameters_list (SymbolDBEngine *dbe, static_query_type query_id);
 
-extern inline const DynChildQueryNode *
+extern GNUC_INLINE const DynChildQueryNode *
 sdb_engine_get_dyn_query_node_by_id (SymbolDBEngine *dbe, dyn_query_type query_id,
 									 SymExtraInfo sym_info, gsize other_parameters);
 
-extern inline const DynChildQueryNode *
+extern GNUC_INLINE const DynChildQueryNode *
 sdb_engine_insert_dyn_query_node_by_id (SymbolDBEngine *dbe, dyn_query_type query_id,
 									 	SymExtraInfo sym_info, gsize other_parameters,
 										const gchar *sql);
@@ -319,117 +319,117 @@ symbol_db_util_is_pattern_exact_match (const gchar *pattern)
 }
 
 GPtrArray *
-symbol_db_util_fill_type_array (IAnjutaSymbolType match_types)
+symbol_db_util_fill_type_array (SymType match_types)
 {
 	GPtrArray *filter_array;
 	filter_array = g_ptr_array_new ();
 
-	if (match_types & IANJUTA_SYMBOL_TYPE_CLASS)
+	if (match_types & SYMTYPE_CLASS)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("class"));
 	}
 
-	if (match_types & IANJUTA_SYMBOL_TYPE_ENUM)
+	if (match_types & SYMTYPE_ENUM)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("enum"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_ENUMERATOR)
+	if (match_types & SYMTYPE_ENUMERATOR)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("enumerator"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_FIELD)
+	if (match_types & SYMTYPE_FIELD)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("field"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_FUNCTION)
+	if (match_types & SYMTYPE_FUNCTION)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("function"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_INTERFACE)
+	if (match_types & SYMTYPE_INTERFACE)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("interface"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_MEMBER)
+	if (match_types & SYMTYPE_MEMBER)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("member"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_METHOD)
+	if (match_types & SYMTYPE_METHOD)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("method"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_NAMESPACE)
+	if (match_types & SYMTYPE_NAMESPACE)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("namespace"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_PACKAGE)
+	if (match_types & SYMTYPE_PACKAGE)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("package"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_PROTOTYPE)
+	if (match_types & SYMTYPE_PROTOTYPE)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("prototype"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_STRUCT)
+	if (match_types & SYMTYPE_STRUCT)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("struct"));
 	}
 
-	if (match_types & IANJUTA_SYMBOL_TYPE_TYPEDEF)
+	if (match_types & SYMTYPE_TYPEDEF)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("typedef"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_STRUCT)
+	if (match_types & SYMTYPE_STRUCT)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("struct"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_UNION)
+	if (match_types & SYMTYPE_UNION)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("union"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_VARIABLE)
+	if (match_types & SYMTYPE_VARIABLE)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("variable"));
 	}
 				
-	if (match_types & IANJUTA_SYMBOL_TYPE_EXTERNVAR)
+	if (match_types & SYMTYPE_EXTERNVAR)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("externvar"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_MACRO)
+	if (match_types & SYMTYPE_MACRO)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("macro"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG)
+	if (match_types & SYMTYPE_MACRO_WITH_ARG)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("macro_with_arg"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_FILE)
+	if (match_types & SYMTYPE_FILE)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("file"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_VARIABLE)
+	if (match_types & SYMTYPE_VARIABLE)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("variable"));
 	}
 	
-	if (match_types & IANJUTA_SYMBOL_TYPE_OTHER)
+	if (match_types & SYMTYPE_OTHER)
 	{
 		g_ptr_array_add (filter_array, g_strdup ("other"));
 	}
@@ -447,3 +447,72 @@ symbol_db_util_get_sym_type_conversion_hash (SymbolDBEngine *dbe)
 		
 	return priv->sym_type_conversion_hash;
 }
+
+GPtrArray* 
+symbol_db_util_get_c_source_files (const gchar* dir)
+{
+	GHashTable *mimes;
+	GPtrArray *res;
+
+	mimes = g_hash_table_new (g_str_hash, g_str_equal);
+	g_hash_table_insert (mimes, "text/x-csrc", "text/x-csrc");
+	g_hash_table_insert (mimes, "text/x-chdr", "text/x-chdr");
+
+	res = symbol_db_util_get_source_files_by_mime (dir, mimes);
+	
+	g_hash_table_destroy (mimes);
+	return res;
+}
+
+GPtrArray * 
+symbol_db_util_get_source_files_by_mime (const gchar* dir, const GHashTable *mimes)
+{
+	GPtrArray* files = g_ptr_array_new();
+	GFile *file;
+	GFileEnumerator *enumerator;
+	GFileInfo* info;
+	GError *error = NULL;
+	gchar *buildable_dir;
+
+	g_return_val_if_fail (dir != NULL, NULL);
+	g_return_val_if_fail (mimes != NULL, NULL);
+		
+	if ((file = g_file_new_for_commandline_arg (dir)) == NULL)
+		return NULL;
+		
+	enumerator = g_file_enumerate_children (file, 
+			G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","
+			G_FILE_ATTRIBUTE_STANDARD_NAME,
+			G_FILE_QUERY_INFO_NONE,
+			NULL, &error);
+	
+	if (!enumerator)
+	{
+		g_warning ("Could not enumerate: %s %s\n", 
+				g_file_get_path (file),
+				error->message);
+		g_error_free (error);
+		g_object_unref (file);
+		return files;
+	}
+
+	buildable_dir = g_file_get_path (file);
+		
+	for (info = g_file_enumerator_next_file (enumerator, NULL, NULL); info != NULL; 
+			info = g_file_enumerator_next_file (enumerator, NULL, NULL))
+	{
+		const gchar *mime_type = g_file_info_get_content_type (info);
+		if (!mime_type)
+			continue;
+		if (g_hash_table_lookup ((GHashTable*)mimes, mime_type) != NULL)
+		{
+			g_ptr_array_add (files, g_build_filename (buildable_dir, g_file_info_get_name (info), NULL));
+		}
+	}
+
+	g_free (buildable_dir);
+	g_object_unref (enumerator);
+	g_object_unref (file);
+		
+	return files;
+}
